@@ -97,7 +97,7 @@ void Smb4KBookmarkHandler::addBookmark(const BookmarkPtr &bookmark)
         BookmarkPtr knownBookmark = findBookmarkByUrl(bookmark->url());
 
         if (knownBookmark) {
-            Smb4KNotification::bookmarkExists(knownBookmark.data());
+            Smb4KNotification::bookmarkExists(knownBookmark);
             return;
         }
 
@@ -146,7 +146,7 @@ void Smb4KBookmarkHandler::addBookmarks(const QList<SharePtr> &list)
         BookmarkPtr knownBookmark = findBookmarkByUrl(share->isHomesShare() ? share->homeUrl() : share->url());
 
         if (knownBookmark) {
-            Smb4KNotification::bookmarkExists(knownBookmark.data());
+            Smb4KNotification::bookmarkExists(knownBookmark);
             continue;
         }
 
@@ -203,7 +203,7 @@ void Smb4KBookmarkHandler::addBookmarks(const QList<BookmarkPtr> &list, bool rep
         // Check if the bookmark label is already in use
         //
         if (!bookmark->label().isEmpty() && findBookmarkByLabel(bookmark->label())) {
-            Smb4KNotification::bookmarkLabelInUse(bookmark.data());
+            Smb4KNotification::bookmarkLabelInUse(bookmark);
             bookmark->setLabel(bookmark->label() + QStringLiteral(" (1)"));
         }
 
@@ -437,24 +437,21 @@ BookmarkPtr Smb4KBookmarkHandler::findBookmarkByLabel(const QString &label)
 
 QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList() const
 {
-    // Update the bookmarks
+    QList<BookmarkPtr> bookmarks;
+
     update();
 
-    // Get the list of the bookmarks
     if (Smb4KSettings::useProfiles()) {
-        QList<BookmarkPtr> bookmarks;
-
         for (const BookmarkPtr &bookmark : qAsConst(d->bookmarks)) {
             if (bookmark->profile() == Smb4KSettings::activeProfile()) {
                 bookmarks << bookmark;
             }
         }
-
-        return bookmarks;
+    } else {
+        bookmarks = d->bookmarks;
     }
 
-    // Return the list of bookmarks
-    return d->bookmarks;
+    return bookmarks;
 }
 
 QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList(const QString &categoryName) const
@@ -476,9 +473,9 @@ QStringList Smb4KBookmarkHandler::categoryList() const
     QStringList categories;
     QList<BookmarkPtr> temporalBookmarkList = bookmarksList();
 
-    for (const BookmarkPtr &b : qAsConst(temporalBookmarkList)) {
-        if (!categories.contains(b->categoryName())) {
-            categories << b->categoryName();
+    for (const BookmarkPtr &bookmark : qAsConst(temporalBookmarkList)) {
+        if (!categories.contains(bookmark->categoryName())) {
+            categories << bookmark->categoryName();
         }
     }
 
