@@ -1,27 +1,9 @@
-/***************************************************************************
+/*
     Smb4K's container class for information about a host.
-                             -------------------
-    begin                : Sa Jan 26 2008
-    copyright            : (C) 2008-2019 by Alexander Reinholdt
-    email                : alexander.reinholdt@kdemail.net
- ***************************************************************************/
 
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful, but   *
- *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
- *   General Public License for more details.                              *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Suite 500, Boston,*
- *   MA 02110-1335, USA                                                    *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2008-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef SMB4KHOST_H
 #define SMB4KHOST_H
@@ -30,15 +12,14 @@
 #include "smb4kbasicnetworkitem.h"
 
 // Qt includes
-#include <QString>
-#include <QScopedPointer>
 #include <QHostAddress>
+#include <QScopedPointer>
+#include <QString>
 
 // forward declarations
 class Smb4KAuthInfo;
 class Smb4KHostPrivate;
 
-
 /**
  * This class is a container that carries information about a host found in
  * the network neighborhood. It is part of the core classes of Smb4K.
@@ -48,29 +29,25 @@ class Smb4KHostPrivate;
 
 class Q_DECL_EXPORT Smb4KHost : public Smb4KBasicNetworkItem
 {
-  friend class Smb4KHostPrivate;
-  
-  public:
+    friend class Smb4KHostPrivate;
+
+public:
     /**
-     * The default constructor. It takes the name of the host as only argument.
-     * You have to set all other information with the other functions provided
-     * by this class.
+     * This constructor takes the URL @p url as argument.
      *
-     * @param name                The name of the host
+     * @param url           The URL
      */
-    explicit Smb4KHost(const QString &name);
+    explicit Smb4KHost(const QUrl &url);
 
     /**
-     * The copy constructor. This constructor takes a Smb4KHost item as argument
-     * and copies its values.
+     * The copy constructor.
      *
      * @param host                The Smb4KHost object that is to be copied.
      */
     Smb4KHost(const Smb4KHost &host);
 
     /**
-     * The empty constructor. It does not take any argument and you have to set
-     * all information by the other functions provided by this class.
+     * The empty constructor.
      */
     Smb4KHost();
 
@@ -91,7 +68,7 @@ class Q_DECL_EXPORT Smb4KHost : public Smb4KBasicNetworkItem
      *
      * @returns the host's name.
      */
-    QString hostName() const; 
+    QString hostName() const;
 
     /**
      * Set the workgroup where this host is located.
@@ -114,7 +91,7 @@ class Q_DECL_EXPORT Smb4KHost : public Smb4KBasicNetworkItem
      * @param ip                  The IP address of this host.
      */
     void setIpAddress(const QString &ip);
-    
+
     /**
      * Set the IP address of this host. @p ip will only be accepted
      * if it is compatible with either IPv4 or IPv6.
@@ -131,10 +108,10 @@ class Q_DECL_EXPORT Smb4KHost : public Smb4KBasicNetworkItem
      * @returns the host's IP address or an empty string.
      */
     QString ipAddress() const;
-    
+
     /**
      * Returns TRUE if the host's IP address is set and FALSE otherwise.
-     * 
+     *
      * @returns TRUE if the host's IP address is known.
      */
     bool hasIpAddress() const;
@@ -169,51 +146,42 @@ class Q_DECL_EXPORT Smb4KHost : public Smb4KBasicNetworkItem
     int port() const;
 
     /**
-     * Set the authentication information for the host. This function will add
-     * the authentication information to the URL of the host. Any previous
-     * user information including the login will be overwritten.
+     * Set the user name for the host.
      *
-     * @param authInfo    The authentication information
+     * @param name          The login name
      */
-    void setAuthInfo(Smb4KAuthInfo *authInfo);
-    
-    /**
-     * Set the login name for the host.
-     *
-     * @param login               The login name
-     */
-    void setLogin(const QString &login);
+    void setUserName(const QString &name);
 
     /**
-     * Returns the login name.
+     * Returns the user name.
      *
-     * @returns the login name.
+     * @returns the user name.
      */
-    QString login() const;
-    
+    QString userName() const;
+
     /**
      * Set the password used for authentication.
-     * 
+     *
      * @param passwd              The password
      */
     void setPassword(const QString &passwd);
-    
+
     /**
      * Returns the password.
-     * 
+     *
      * @returns the password.
      */
     QString password() const;
-    
+
     /**
      * Updates the host item if the workgroup and host name of @p host and
      * of this item is equal. Otherwise it does nothing.
      * @param host            The share object that is used to update
      *                        this object
      */
-    void update(Smb4KHost *host);    
+    void update(Smb4KHost *host);
 
-  private:
+private:
     const QScopedPointer<Smb4KHostPrivate> d;
 };
 
