@@ -20,7 +20,6 @@
 #include <QUrl>
 
 // forward declarations
-class Smb4KBookmark;
 class Smb4KNotificationPrivate;
 
 /**
@@ -85,7 +84,7 @@ Q_DECL_EXPORT void mimetypeNotSupported(const QString &mimetype);
  *
  * @param bookmark  The bookmark
  */
-Q_DECL_EXPORT void bookmarkExists(Smb4KBookmark *bookmark);
+Q_DECL_EXPORT void bookmarkExists(const BookmarkPtr &bookmark);
 
 /**
  * Tell the user that the label he/she chose for the bookmark is already
@@ -93,7 +92,7 @@ Q_DECL_EXPORT void bookmarkExists(Smb4KBookmark *bookmark);
  *
  * @param bookmark  The bookmark
  */
-Q_DECL_EXPORT void bookmarkLabelInUse(Smb4KBookmark *bookmark);
+Q_DECL_EXPORT void bookmarkLabelInUse(const BookmarkPtr &bookmark);
 
 /**
  * This error message is shown if the mounting of a share failed.
@@ -180,7 +179,7 @@ Q_DECL_EXPORT void mkdirFailed(const QDir &dir);
 /**
  * This error message is shown if a process threw an error.
  *
- * @param proc_err  The code describing the process error
+ * @param error     The code describing the process error
  */
 Q_DECL_EXPORT void processError(QProcess::ProcessError error);
 
@@ -209,6 +208,14 @@ Q_DECL_EXPORT void invalidURLPassed();
  * @param errorMessage  The error message
  */
 Q_DECL_EXPORT void networkCommunicationFailed(const QString &errorMessage);
+
+/**
+ * This error message is shown when an error with the Zeroconf daemon
+ * (Avahi or mDNS) occurred.
+ *
+ * @param errorMessage  The error message
+ */
+Q_DECL_EXPORT void zeroconfError(const QString &errorMessage);
 };
 
 #endif
