@@ -1,27 +1,9 @@
-/***************************************************************************
+/*
     This is the new synchronizer of Smb4K.
-                             -------------------
-    begin                : Fr Feb 04 2011
-    copyright            : (C) 2011-2019 by Alexander Reinholdt
-    email                : alexander.reinholdt@kdemail.net
- ***************************************************************************/
 
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful, but   *
- *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
- *   General Public License for more details.                              *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Suite 500, Boston,*
- *   MA 02110-1335, USA                                                    *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2011-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef SMB4KSYNCHRONIZER_H
 #define SMB4KSYNCHRONIZER_H
@@ -30,8 +12,8 @@
 #include "smb4kglobal.h"
 
 // Qt includes
-#include <QString>
 #include <QScopedPointer>
+#include <QString>
 
 // KDE includes
 #include <KCoreAddons/KCompositeJob>
@@ -41,21 +23,21 @@ class Smb4KSynchronizerPrivate;
 
 class Q_DECL_EXPORT Smb4KSynchronizer : public KCompositeJob
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  friend class Smb4KSynchronizerPrivate;
+    friend class Smb4KSynchronizerPrivate;
 
-  public:
+public:
     /**
      * The constructor
      */
-    explicit Smb4KSynchronizer(QObject *parent = 0);
+    explicit Smb4KSynchronizer(QObject *parent = nullptr);
 
     /**
      * The destructor
      */
     ~Smb4KSynchronizer();
-    
+
     /**
      * This function returns a static pointer to this class.
      *
@@ -81,15 +63,15 @@ class Q_DECL_EXPORT Smb4KSynchronizer : public KCompositeJob
     bool isRunning();
 
     /**
-     * With this function you can test whether a synchronization job 
+     * With this function you can test whether a synchronization job
      * for a certain share @param share is already running.
-     * 
+     *
      * @returns TRUE if a synchronization process is already running
      */
     bool isRunning(const SharePtr &share);
 
     /**
-     * This function either aborts the synchronization for a certain 
+     * This function either aborts the synchronization for a certain
      * mounted share, if a valid pointer is passed, or aborts all running
      * processes.
      *
@@ -102,7 +84,7 @@ class Q_DECL_EXPORT Smb4KSynchronizer : public KCompositeJob
      */
     void start() override;
 
-  Q_SIGNALS:
+Q_SIGNALS:
     /**
      * This signal is emitted when a job is started. The emitted path
      * is the one of the destination.
@@ -118,13 +100,13 @@ class Q_DECL_EXPORT Smb4KSynchronizer : public KCompositeJob
      * @param dest        The destination's URL
      */
     void finished(const QString &dest);
-    
-  protected Q_SLOTS:
+
+protected Q_SLOTS:
     /**
      * Invoked by start() function
      */
     void slotStartJobs();
-    
+
     /**
      * Invoked when a job finished
      */
@@ -135,7 +117,7 @@ class Q_DECL_EXPORT Smb4KSynchronizer : public KCompositeJob
      */
     void slotAboutToQuit();
 
-  private:
+private:
     /**
      * Pointer to Smb4KSearchPrivate class
      */
