@@ -1,57 +1,38 @@
-/***************************************************************************
-    This file contains private helper classes for the Smb4KSynchronizer 
+/*
+    This file contains private helper classes for the Smb4KSynchronizer
     class.
-                             -------------------
-    begin                : Fr Okt 24 2008
-    copyright            : (C) 2008-2019 by Alexander Reinholdt
-    email                : alexander.reinholdt@kdemail.net
- ***************************************************************************/
 
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful, but   *
- *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
- *   General Public License for more details.                              *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Suite 500, Boston,*
- *   MA 02110-1335, USA                                                    *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2008-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef SMB4KSYNCHRONIZER_P_H
 #define SMB4KSYNCHRONIZER_P_H
 
 // application specific includes
-#include "smb4ksynchronizer.h"
 #include "smb4kglobal.h"
+#include "smb4ksynchronizer.h"
 
 // Qt includes
-#include <QUrl>
 #include <QDialog>
 #include <QPushButton>
+#include <QUrl>
 
 // KDE includes
 #include <KCoreAddons/KJob>
 #include <KCoreAddons/KProcess>
 #include <KIOWidgets/KUrlRequester>
 #include <KJobWidgets/KUiServerJobTracker>
-    
 
 class Smb4KSyncJob : public KJob
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     /**
      * Constructor
      */
-    explicit Smb4KSyncJob(QObject *parent = 0);
+    explicit Smb4KSyncJob(QObject *parent = nullptr);
 
     /**
      * Destructor
@@ -64,7 +45,7 @@ class Smb4KSyncJob : public KJob
     void start() override;
 
     /**
-     * Setup the synchronization process. This function must be 
+     * Setup the synchronization process. This function must be
      * called before start() is run.
      *
      * @param share     The share
@@ -76,16 +57,22 @@ class Smb4KSyncJob : public KJob
      *
      * @returns the source directory.
      */
-    const QUrl &source() { return m_src; }
+    const QUrl &source()
+    {
+        return m_sourceUrl;
+    }
 
     /**
      * Returns the destination directory.
      *
      * @returns the destination directory.
      */
-    const QUrl &destination() { return m_dest; }
+    const QUrl &destination()
+    {
+        return m_destinationUrl;
+    }
 
-  Q_SIGNALS:
+Q_SIGNALS:
     /**
      * This signal is emitted when a job is started. The emitted path
      * is the one of the destination.
@@ -101,34 +88,34 @@ class Smb4KSyncJob : public KJob
      * @param dest        The destination's URL
      */
     void finished(const QString &dest);
-     
-  protected:
+
+protected:
     /**
      * Reimplemented from KJob. Kills the internal process and
      * then the job itself.
      */
     bool doKill() override;
-    
-  protected Q_SLOTS:
+
+protected Q_SLOTS:
     void slotStartSynchronization();
     void slotReadStandardOutput();
     void slotReadStandardError();
     void slotProcessFinished(int exitCode, QProcess::ExitStatus status);
 
-  private:
+private:
     SharePtr m_share;
-    QUrl m_src;
-    QUrl m_dest;
+    QUrl m_sourceUrl;
+    QUrl m_destinationUrl;
     KProcess *m_process;
     KUiServerJobTracker *m_job_tracker;
+    bool m_terminated;
 };
 
-
 class Smb4KSynchronizationDialog : public QDialog
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     /**
      * The constructor
      *
@@ -136,7 +123,7 @@ class Smb4KSynchronizationDialog : public QDialog
      *
      * @param parent        The parent widget
      */
-    explicit Smb4KSynchronizationDialog(const SharePtr &share, QWidget *parent = 0);
+    explicit Smb4KSynchronizationDialog(const SharePtr &share, QWidget *parent = nullptr);
 
     /**
      * The destructor
@@ -153,16 +140,16 @@ class Smb4KSynchronizationDialog : public QDialog
      */
     const QUrl destination();
 
-  protected Q_SLOTS:
+protected Q_SLOTS:
     void slotCancelClicked();
     void slotSynchronizeClicked();
     void slotSwapPathsClicked();
 
-  private:
+private:
     QPushButton *m_swap_button;
     QPushButton *m_synchronize_button;
     QPushButton *m_cancel_button;
-    
+
     /**
      * A pointer to the share object
      */
@@ -179,15 +166,13 @@ class Smb4KSynchronizationDialog : public QDialog
     KUrlRequester *m_destination;
 };
 
-
 class Smb4KSynchronizerPrivate
 {
 };
 
-
 class Smb4KSynchronizerStatic
 {
-  public:
+public:
     Smb4KSynchronizer instance;
 };
 
