@@ -1,27 +1,9 @@
-/***************************************************************************
+/*
     Smb4K's container class for information about a workgroup.
-                             -------------------
-    begin                : Sa Jan 26 2008
-    copyright            : (C) 2008-2020 by Alexander Reinholdt
-    email                : alexander.reinholdt@kdemail.net
- ***************************************************************************/
 
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful, but   *
- *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
- *   General Public License for more details.                              *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Suite 500, Boston,*
- *   MA 02110-1335, USA                                                    *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2008-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef SMB4KWORKGROUP_H
 #define SMB4KWORKGROUP_H
@@ -30,10 +12,9 @@
 #include "smb4kbasicnetworkitem.h"
 
 // Qt includes
-#include <QString>
-#include <QScopedPointer>
 #include <QHostAddress>
-
+#include <QScopedPointer>
+#include <QString>
 
 // forward declarations
 class Smb4KWorkgroupPrivate;
@@ -48,9 +29,9 @@ class Smb4KWorkgroupPrivate;
 
 class Q_DECL_EXPORT Smb4KWorkgroup : public Smb4KBasicNetworkItem
 {
-  friend class Smb4KWorkgroupPrivate;
-  
-  public:
+    friend class Smb4KWorkgroupPrivate;
+
+public:
     /**
      * The default constructor. It takes the name of the workgroup as only
      * argument. You have to set all other information by the other functions
@@ -58,7 +39,7 @@ class Q_DECL_EXPORT Smb4KWorkgroup : public Smb4KBasicNetworkItem
      *
      * @param name            The name of the workgroup or domain.
      */
-    explicit Smb4KWorkgroup(const QString &name);
+    SMB4K_DEPRECATED explicit Smb4KWorkgroup(const QString &name);
 
     /**
      * The copy constructor. This constructor takes another Smb4KWorkgroup item
@@ -106,11 +87,11 @@ class Q_DECL_EXPORT Smb4KWorkgroup : public Smb4KBasicNetworkItem
      * @returns the name of the master browser.
      */
     QString masterBrowserName() const;
-    
+
     /**
-     * Returns TRUE if there is a master browser and FALSE otherwise. No master 
+     * Returns TRUE if there is a master browser and FALSE otherwise. No master
      * browser might be defined, if the DNS-SD method is used.
-     * 
+     *
      * @returns TRUE if there is a master browser.
      */
     bool hasMasterBrowser() const;
@@ -122,11 +103,11 @@ class Q_DECL_EXPORT Smb4KWorkgroup : public Smb4KBasicNetworkItem
      * @param ip              The master browser's IP address
      */
     void setMasterBrowserIpAddress(const QString &ip);
-    
+
     /**
      * Set the IP address of the master browser. @p address will only be accepted
      * if it is compatible with either IPv4 or IPv6.
-     * 
+     *
      * @param address         The master browser's IP address
      */
     void setMasterBrowserIpAddress(const QHostAddress &address);
@@ -139,9 +120,9 @@ class Q_DECL_EXPORT Smb4KWorkgroup : public Smb4KBasicNetworkItem
      * @returns the IP address of the master browser or an empty string.
      */
     QString masterBrowserIpAddress() const;
-    
+
     /**
-     * Returns TRUE if the workgroup/domain master browsers IP address is set and 
+     * Returns TRUE if the workgroup/domain master browsers IP address is set and
      * FALSE otherwise.
      *
      * @returns TRUE if the master browsers IP address is known.
@@ -156,7 +137,7 @@ class Q_DECL_EXPORT Smb4KWorkgroup : public Smb4KBasicNetworkItem
      */
     void update(Smb4KWorkgroup *workgroup);
 
-  private:
+private:
     const QScopedPointer<Smb4KWorkgroupPrivate> d;
 };
 
