@@ -1,27 +1,9 @@
-/***************************************************************************
+/*
     The helper that mounts and unmounts shares.
-                             -------------------
-    begin                : Sa Okt 16 2010
-    copyright            : (C) 2010-2020 by Alexander Reinholdt
-    email                : alexander.reinholdt@kdemail.net
- ***************************************************************************/
 
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful, but   *
- *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
- *   General Public License for more details.                              *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Suite 500, Boston,*
- *   MA 02110-1335, USA                                                    *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2010-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // application specific includes
 #include "smb4kmounthelper.h"
@@ -29,12 +11,9 @@
 
 // Qt includes
 #include <QDebug>
-#include <QLatin1String>
 #include <QNetworkInterface>
 #include <QProcessEnvironment>
 #include <QUrl>
-#include <QEventLoop>
-#include <QTimer>
 
 // KDE includes
 #include <KAuth/KAuthHelperSupport>
@@ -60,12 +39,7 @@ KAuth::ActionReply Smb4KMountHelper::mount(const QVariantMap &args)
     QList<QNetworkInterface> interfaces = QNetworkInterface::allInterfaces();
 
     for (const QNetworkInterface &interface : qAsConst(interfaces)) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-        if (interface.isValid() && interface.type() != QNetworkInterface::Loopback && interface.flags() & QNetworkInterface::IsRunning && !online)
-#else
-        if (interface.isValid() && !(interface.flags() & QNetworkInterface::IsLoopBack) && interface.flags() & QNetworkInterface::IsRunning && !online)
-#endif
-        {
+        if (interface.isValid() && interface.type() != QNetworkInterface::Loopback && interface.flags() & QNetworkInterface::IsRunning && !online) {
             online = true;
             break;
         }
@@ -84,7 +58,7 @@ KAuth::ActionReply Smb4KMountHelper::mount(const QVariantMap &args)
     //
     // Check the mount executable
     //
-    if (mount != args["mh_command"].toString()) {
+    if (mount != args[QStringLiteral("mh_command")].toString()) {
         // Something weird is going on, bail out.
         reply.setType(ActionReply::HelperErrorType);
         return reply;
@@ -96,14 +70,14 @@ KAuth::ActionReply Smb4KMountHelper::mount(const QVariantMap &args)
     QStringList command;
 #if defined(Q_OS_LINUX)
     command << mount;
-    command << args["mh_url"].toUrl().toString(QUrl::RemoveScheme | QUrl::RemoveUserInfo | QUrl::RemovePort);
-    command << args["mh_mountpoint"].toString();
-    command << args["mh_options"].toStringList();
+    command << args[QStringLiteral("mh_url")].toUrl().toString(QUrl::RemoveScheme | QUrl::RemoveUserInfo | QUrl::RemovePort);
+    command << args[QStringLiteral("mh_mountpoint")].toString();
+    command << args[QStringLiteral("mh_options")].toStringList();
 #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
     command << mount;
-    command << args["mh_options"].toStringList();
-    command << args["mh_url"].toUrl().toString(QUrl::RemoveScheme | QUrl::RemoveUserInfo | QUrl::RemovePort);
-    command << args["mh_mountpoint"].toString();
+    command << args[QStringLiteral("mh_options")].toStringList();
+    command << args[QStringLiteral("mh_url")].toUrl().toString(QUrl::RemoveScheme | QUrl::RemoveUserInfo | QUrl::RemovePort);
+    command << args[QStringLiteral("mh_mountpoint")].toString();
 #endif
 
     //
@@ -113,14 +87,14 @@ KAuth::ActionReply Smb4KMountHelper::mount(const QVariantMap &args)
     proc.setOutputChannelMode(KProcess::SeparateChannels);
     proc.setProcessEnvironment(QProcessEnvironment::systemEnvironment());
 #if defined(Q_OS_LINUX)
-    proc.setEnv("PASSWD", args["mh_url"].toUrl().password().toUtf8().data(), true);
+    proc.setEnv(QStringLiteral("PASSWD"), args[QStringLiteral("mh_url")].toUrl().password(), true);
 #endif
     // We need this to avoid a translated password prompt.
-    proc.setEnv("LANG", "C");
+    proc.setEnv(QStringLiteral("LANG"), QStringLiteral("C"));
     // If the location of a Kerberos ticket is passed, it needs to
     // be passed to the process environment here.
-    if (args.contains("mh_krb5ticket")) {
-        proc.setEnv("KRB5CCNAME", args["mh_krb5ticket"].toString());
+    if (args.contains(QStringLiteral("mh_krb5ticket"))) {
+        proc.setEnv(QStringLiteral("KRB5CCNAME"), args[QStringLiteral("mh_krb5ticket")].toString());
     }
 
     proc.setProgram(command);
@@ -137,26 +111,24 @@ KAuth::ActionReply Smb4KMountHelper::mount(const QVariantMap &args)
                 proc.kill();
                 break;
             }
-            
+
             // Check if there is a password prompt. If there is one, pass
             // the password to it.
             QByteArray out = proc.readAllStandardError();
 
             if (out.startsWith("Password")) {
-                proc.write(args["mh_url"].toUrl().password().toUtf8().data());
+                proc.write(args[QStringLiteral("mh_url")].toUrl().password().toUtf8().data());
                 proc.write("\r");
             }
-            
+
             timeout += 10;
-            
-            QEventLoop loop;
-            QTimer::singleShot(10, &loop, SLOT(quit()));
-            loop.exec();
+
+            wait(10);
         }
 
         if (proc.exitStatus() == KProcess::NormalExit) {
             QString stdErr = QString::fromUtf8(proc.readAllStandardError());
-            reply.addData("mh_error_message", stdErr.trimmed());
+            reply.addData(QStringLiteral("mh_error_message"), stdErr.trimmed());
         }
     } else {
         reply.setType(ActionReply::HelperErrorType);
@@ -178,7 +150,7 @@ KAuth::ActionReply Smb4KMountHelper::unmount(const QVariantMap &args)
     //
     // Check the mount executable
     //
-    if (umount != args["mh_command"].toString()) {
+    if (umount != args[QStringLiteral("mh_command")].toString()) {
         // Something weird is going on, bail out.
         reply.setType(ActionReply::HelperErrorType);
         return reply;
@@ -191,14 +163,9 @@ KAuth::ActionReply Smb4KMountHelper::unmount(const QVariantMap &args)
     KMountPoint::List mountPoints = KMountPoint::currentMountPoints(KMountPoint::BasicInfoNeeded | KMountPoint::NeedMountOptions);
 
     for (const QExplicitlySharedDataPointer<KMountPoint> &mountPoint : qAsConst(mountPoints)) {
-#if defined(Q_OS_LINUX)
-        if (QString::compare(args["mh_mountpoint"].toString(), mountPoint->mountPoint()) == 0
-            && QString::compare(mountPoint->mountType(), "cifs", Qt::CaseInsensitive) == 0)
-#else
-        if (QString::compare(args["mh_mountpoint"].toString(), mountPoint->mountPoint()) == 0
-            && QString::compare(mountPoint->mountType(), "smbfs", Qt::CaseInsensitive) == 0)
-#endif
-        {
+        if (args[QStringLiteral("mh_mountpoint")].toString() == mountPoint->mountPoint()
+            && (mountPoint->mountType() == QStringLiteral("cifs") || mountPoint->mountType() == QStringLiteral("smb3")
+                || mountPoint->mountType() == QStringLiteral("smbfs"))) {
             mountPointOk = true;
             break;
         }
@@ -209,7 +176,7 @@ KAuth::ActionReply Smb4KMountHelper::unmount(const QVariantMap &args)
     //
     if (!mountPointOk) {
         reply.setType(ActionReply::HelperErrorType);
-        reply.setErrorDescription(i18n("The mountpoint %1 is invalid.", args["mh_mountpoint"].toString()));
+        reply.setErrorDescription(i18n("The mountpoint %1 is invalid.", args[QStringLiteral("mh_mountpoint")].toString()));
     }
 
     //
@@ -217,8 +184,8 @@ KAuth::ActionReply Smb4KMountHelper::unmount(const QVariantMap &args)
     //
     QStringList command;
     command << umount;
-    command << args["mh_options"].toStringList();
-    command << args["mh_mountpoint"].toString();
+    command << args[QStringLiteral("mh_options")].toStringList();
+    command << args[QStringLiteral("mh_mountpoint")].toString();
 
     //
     // The process
@@ -239,12 +206,7 @@ KAuth::ActionReply Smb4KMountHelper::unmount(const QVariantMap &args)
     QList<QNetworkInterface> interfaces = QNetworkInterface::allInterfaces();
 
     for (const QNetworkInterface &interface : qAsConst(interfaces)) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-        if (interface.isValid() && interface.type() != QNetworkInterface::Loopback && interface.flags() & QNetworkInterface::IsRunning && !online)
-#else
-        if (interface.isValid() && !(interface.flags() & QNetworkInterface::IsLoopBack) && interface.flags() & QNetworkInterface::IsRunning && !online)
-#endif
-        {
+        if (interface.isValid() && interface.type() != QNetworkInterface::Loopback && interface.flags() & QNetworkInterface::IsRunning && !online) {
             online = true;
             break;
         }
@@ -258,23 +220,21 @@ KAuth::ActionReply Smb4KMountHelper::unmount(const QVariantMap &args)
             // Thus, we implement a loop that checks periodically, if we
             // need to kill the process.
             int timeout = 0;
-            
+
             while (proc.state() != KProcess::NotRunning) {
                 if (HelperSupport::isStopped() || timeout == 30000) {
                     proc.kill();
                     break;
                 }
-                
+
                 timeout += 10;
 
-                QEventLoop loop;
-                QTimer::singleShot(10, &loop, SLOT(quit()));
-                loop.exec();
+                wait(10);
             }
 
             if (proc.exitStatus() == KProcess::NormalExit) {
                 QString stdErr = QString::fromUtf8(proc.readAllStandardError());
-                reply.addData("mh_error_message", stdErr.trimmed());
+                reply.addData(QStringLiteral("mh_error_message"), stdErr.trimmed());
             }
         } else {
             reply.setType(ActionReply::HelperErrorType);
