@@ -1,7 +1,7 @@
 /*
-    The configuration page for the custom options
+    The configuration page for the custom settings
 
-    SPDX-FileCopyrightText: 2013-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2013-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -119,7 +119,7 @@ protected Q_SLOTS:
     void slotEnableResetButton();
 
 private:
-    bool m_customOptionsChanged;
+    bool m_customSettingsChanged;
 };
 
 #endif
