@@ -440,7 +440,8 @@ void Smb4KConfigPageMounting::setupWidget()
     advancedOptionsExtraWidgetLayout->addWidget(securityMode, 2, 1);
 
     // Additional options
-    QLabel *additionalOptionsLabel = new QLabel(Smb4KMountSettings::self()->customCIFSOptionsItem()->label(), advancedOptionsExtraWidget);
+    QCheckBox *useAdditionalCifsOptions = new QCheckBox(Smb4KMountSettings::self()->useCustomCifsOptionsItem()->label(), advancedOptionsExtraWidget);
+    useAdditionalCifsOptions->setObjectName(QStringLiteral("kcfg_UseCustomCifsOptions"));
 
     QWidget *additionalOptionsWidget = new QWidget(advancedOptionsExtraWidget);
     QHBoxLayout *additionalOptionsWidgetLayout = new QHBoxLayout(additionalOptionsWidget);
@@ -450,7 +451,6 @@ void Smb4KConfigPageMounting::setupWidget()
     additionalOptions->setObjectName(QStringLiteral("kcfg_CustomCIFSOptions"));
     additionalOptions->setReadOnly(true);
     additionalOptions->setClearButtonEnabled(true);
-    additionalOptionsLabel->setBuddy(additionalOptions);
 
     QToolButton *additionalOptionsEdit = new QToolButton(advancedOptionsExtraWidget);
     additionalOptionsEdit->setIcon(KDE::icon(QStringLiteral("document-edit")));
@@ -459,7 +459,7 @@ void Smb4KConfigPageMounting::setupWidget()
     additionalOptionsWidgetLayout->addWidget(additionalOptions, 0);
     additionalOptionsWidgetLayout->addWidget(additionalOptionsEdit, 0);
 
-    advancedOptionsExtraWidgetLayout->addWidget(additionalOptionsLabel, 3, 0);
+    advancedOptionsExtraWidgetLayout->addWidget(useAdditionalCifsOptions, 3, 0);
     advancedOptionsExtraWidgetLayout->addWidget(additionalOptionsWidget, 3, 1);
 
     advancedOptionsLayout->addWidget(advancedOptionsExtraWidget, 4, 0, 1, 2);
@@ -481,7 +481,7 @@ void Smb4KConfigPageMounting::setupWidget()
     connect(userMenu, SIGNAL(triggered(QAction *)), this, SLOT(slotNewUserTriggered(QAction *)));
     connect(groupMenu, SIGNAL(triggered(QAction *)), this, SLOT(slotNewGroupTriggered(QAction *)));
     connect(cifsExtensionsSupport, SIGNAL(toggled(bool)), this, SLOT(slotCIFSUnixExtensionsSupport(bool)));
-    connect(additionalOptionsEdit, SIGNAL(toggled(bool)), this, SLOT(slotAdditionalCIFSOptions()));
+    connect(additionalOptionsEdit, SIGNAL(clicked(bool)), this, SLOT(slotAdditionalCIFSOptions()));
     connect(remountShares, SIGNAL(toggled(bool)), this, SLOT(slotRemountSharesToggled(bool)));
 }
 #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
